@@ -94,8 +94,6 @@ impl Operation {
                                 }
                             },
                         }
-                    } else if name == "deprecated" {
-                        deprecated = true;
                     } else if name == "param" || name == "parameter" {
                         match value.parse_with(|input: ParseStream| input.parse::<Param>()) {
                             Ok(r) => {
@@ -181,6 +179,9 @@ impl Operation {
                 }
 
                 false
+            } else if attr.path.is_ident("deprecated") {
+                deprecated = true;
+                true
             } else if attr.path.is_ident("doc") {
                 if let Ok(d) = syn::parse2::<DocString>(attr.tokens.clone()) {
                     let val = d.content.value();
